@@ -1,69 +1,64 @@
 from os import PathLike
 from pathlib import Path
 from typing import Dict, Any, List
-from rich.console import Console
-from packaging import version
 
-from .batchruntomo_config.io import read_adoc
-from .constants import TARGET_PIXEL_SIZE_FOR_ALIGNMENT, BATCHRUNTOMO_CONFIG_FIDUCIALS, REQUIRED_IMOD_VERSION
-from .utils import (
-    find_optimal_power_of_2_binning_factor,
-    prepare_imod_directory,
-    run_batchruntomo,
-    imod_is_installed,
-    get_imod_version
-)
+import numpy as np
 
-console = Console(record=True)
+from .utils.io import read_adoc
+from .constants import TARGET_PIXEL_SIZE_FOR_ALIGNMENT, BATCHRUNTOMO_CONFIG_FIDUCIALS
+from .utils.binning import find_optimal_power_of_2_binning_factor
+from .utils.etomo import prepare_etomo_directory, run_batchruntomo, EtomoOutput
+from .utils.installation import check_imod_installation
 
-def run_fiducial_based_alignment(
-        tilt_series_file: Path,
+
+def align_tilt_series_using_fiducials(
+        tilt_series: np.ndarray,
         tilt_angles: List[float],
         pixel_size: float,
         fiducial_size: float,
         nominal_rotation_angle: float,
+        basename: str,
         output_directory: Path,
-):
+) -> EtomoOutput:
     """Run fiducial based alignment in IMOD on a single tilt-series.
 
     Parameters
     ----------
-    tilt_series_file: file containing tilt-series images.
-        File must be compatible with the version of IMOD installed.
+    tilt_series: (n, y, x) array of 2D tilt-images in a tilt-series.
     tilt_angles: nominal stage tilt-angles from the microscope.
     pixel_size: nominal pixel size in Angstroms per pixel.
     fiducial_size: approximate size of fiducials in nanometers.
     nominal_rotation_angle: initial estimate for the rotation angle of the tilt
         axis. https://bio3d.colorado.edu/imod/doc/tomoguide.html#UnknownAxisAngle
+    basename: basename for files in Etomo directory.
     output_directory: tilt-series directory for IMOD.
     """
-    if not imod_is_installed():
-        e = 'No IMOD installation found.'
-        console.log(f'ERROR: {e}')
-        raise RuntimeError(e)
-    imod_version = get_imod_version()
-    if imod_version < version.parse(REQUIRED_IMOD_VERSION):
-        e = f'Ensure IMOD version {REQUIRED_IMOD_VERSION} or higher is installed. Your version is {imod_version}'
-        console.log(f'ERROR: {e}')
-    prepare_imod_directory(
-        tilt_series_file=tilt_series_file,
+    check_imod_installation()
+    output_directory = Path(output_directory)
+    etomo_output = prepare_etomo_directory(
+        directory=output_directory,
+        tilt_series=tilt_series,
         tilt_angles=tilt_angles,
-        imod_directory=output_directory
+        basename=basename,
+
     )
-    directive = generate_fiducial_alignment_directive(
-        tilt_series_file=tilt_series_file,
+    directive = generate_alignment_directive(
+        tilt_series_file=etomo_output.tilt_series_file,
         pixel_size=pixel_size,
         fiducial_size=fiducial_size,
         rotation_angle=nominal_rotation_angle
     )
     run_batchruntomo(
-        tilt_series_file=tilt_series_file,
-        imod_directory=output_directory,
+        directory=output_directory,
+        basename=basename,
         directive=directive
     )
+    if etomo_output.contains_alignment_results is False:
+        raise RuntimeError(f'{basename} failed to align correctly.')
+    return etomo_output
 
 
-def generate_fiducial_alignment_directive(
+def generate_alignment_directive(
         tilt_series_file: PathLike,
         pixel_size: float,
         fiducial_size: float,
